Additional resources
====================

- `Nengo documentation <https://www.nengo.ai/>`_: If you are new to
  Nengo, you should start here.

- `Nengo forums <https://forum.nengo.ai/>`_: To get help or ask questions about
  NengoDL, or Nengo in general.

- `GitHub issue tracker <https://github.com/nengo/nengo-dl/issues>`_: To post bug
  reports or make feature requests.

- `TensorFlow documentation <https://www.tensorflow.org/>`_: Knowledge of
  TensorFlow is not required to use NengoDL; however, some familiarity will
  help take advantage of the advanced NengoDL features.
